@@ -846,6 +846,18 @@ class Auth(object):
         })
         return Slack(**params)
 
+    def slack_bot(self, token_secret_name=None):
+        """Connect to Slack API."""
+        from bits.slack import Slack
+        if not token_secret_name:
+            token_secret_name = self.settings['slack']['bot_token']
+        params = self.secrets.resolve({
+            'token': token_secret_name,
+            'env': self.settings['configuration']['environment'],
+            'notifications': self.settings['slack']['notifications'],
+        })
+        return Slack(**params)
+
     def slack_old(self):
         """Connect to Slack API."""
         from bitsapiclient.services.slack import Slack
